@@ -44,11 +44,7 @@ class DiagramDraw(object):
         else:
             self.shadow = kwargs.get('shadow', (0, 0, 0))
 
-        kwargs = dict(code=kwargs.get('code'),
-                      ignore_pil=kwargs.get('ignore_pil'),
-                      nodoctype=kwargs.get('nodoctype'),
-                      scale_ratio=self.scale_ratio,
-                      transparency=kwargs.get('transparency'))
+        kwargs['scale_ratio'] = self.scale_ratio
         drawer = imagedraw.create(self.format, self.filename, self.pagesize(),
                                   shadow_style=diagram.shadow_style, **kwargs)
         if drawer is None:
@@ -56,6 +52,7 @@ class DiagramDraw(object):
             raise RuntimeError(msg)
 
         self.drawer = LineJumpDrawFilter(drawer, self.metrics.cellsize / 2)
+        self.metrics.drawer = self.drawer
 
     @property
     def nodes(self):
@@ -91,10 +88,6 @@ class DiagramDraw(object):
         self._draw_background()
         self.metrics = temp
 
-        # Smoothing background images.
-        if self.format == 'PNG':
-            self.drawer.smoothCanvas()
-
         if self.scale_ratio > 1:
             pagesize = self.pagesize(scaled=True)
             self.drawer.resizeCanvas(pagesize)
