@@ -13,6 +13,7 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
+import functools
 from blockdiag.utils import XY
 
 
@@ -38,15 +39,18 @@ class LazyReciever(object):
                 self.calls.append((method, args, kwargs))
                 return self
 
-        return _
+        if method.__name__ in self.target.nosideeffect_methods:
+            return functools.partial(method, self.target)
+        else:
+            return _
 
     def _find_method(self, name):
         for p in self.target.__class__.__mro__:
             if name in p.__dict__:
                 return p.__dict__[name]
 
-        raise AttributeError("%s instance has no attribute '%s'"
-            % (self.target.__class__.__name__, name))
+        raise AttributeError("%s instance has no attribute '%s'" %
+                             (self.target.__class__.__name__, name))
 
     def _run(self):
         for recv in self.nested:
