@@ -24,6 +24,7 @@ from blockdiag.utils.fontmap import parse_fontpath
 
 class PDFImageDraw(object):
     self_generative_methods = []
+    nosideeffect_methods = ['textsize']
 
     def __init__(self, filename, size, **kwargs):
         self.canvas = canvas.Canvas(filename, pagesize=size)
@@ -118,6 +119,16 @@ class PDFImageDraw(object):
         if 'thick' in kwargs:
             self.canvas.setLineWidth(1)
 
+    def textsize(self, string, font, maxwidth=None, **kwargs):
+        if maxwidth is None:
+            maxwidth = 65535
+
+        box = (0, 0, maxwidth, 65535)
+        textbox = textfolder.get(box, string, font, format='pdf',
+                                 adjustBaseline=True, canvas=self.canvas,
+                                 **kwargs)
+        return textbox.outlinebox.size
+
     def text(self, xy, string, font, **kwargs):
         self.set_font(font)
         self.set_fill_color(kwargs.get('fill'))
@@ -142,7 +153,8 @@ class PDFImageDraw(object):
 
         self.set_font(font)
         lines = textfolder.get(box, string, font, format='pdf',
-                               adjustBaseline=True, canvas=self.canvas, **kwargs)
+                               adjustBaseline=True, canvas=self.canvas,
+                               **kwargs)
 
         if kwargs.get('outline'):
             outline = kwargs.get('outline')
@@ -212,7 +224,7 @@ class PDFImageDraw(object):
                 sys.stderr.write(msg)
                 return
         self.canvas.drawImage(filename, x, y, w, h, mask='auto',
-                                  preserveAspectRatio=True)
+                              preserveAspectRatio=True)
 
     def save(self, filename, size, format):
         # Ignore size and format parameter; compatibility for ImageDrawEx.
