@@ -23,10 +23,14 @@ feGaussianBlur = svgclass('feGaussianBlur')
 
 class SVGImageDrawElement(object):
     self_generative_methods = ['group', 'anchor']
+    nosideeffect_methods = ['textsize']
 
     def __init__(self, svg, parent=None):
         self.svg = svg
-        self.ignore_pil = False
+        if parent and parent.ignore_pil:
+            self.ignore_pil = True
+        else:
+            self.ignore_pil = False
 
     def rgb(self, color):
         if isinstance(color, tuple):
@@ -92,6 +96,15 @@ class SVGImageDrawElement(object):
                  style=self.filter(filter))
         self.svg.addElement(r)
 
+    def textsize(self, string, font, maxwidth=None, **kwargs):
+        if maxwidth is None:
+            maxwidth = 65535
+
+        box = (0, 0, maxwidth, 65535)
+        textbox = textfolder.get(box, string, font,
+                                 ignore_pil=self.ignore_pil, **kwargs)
+        return textbox.outlinebox.size
+
     def text(self, xy, string, font, **kwargs):
         fill = kwargs.get('fill')
 
@@ -251,8 +264,8 @@ class SVGImageDrawElement(object):
 class SVGImageDraw(SVGImageDrawElement):
     def __init__(self, filename, size, **kwargs):
         self.filename = filename
-        super(SVGImageDraw, self).__init__(svg(0, 0, size[0], size[1]))
-        self.svg.use_doctype = not kwargs.get('nodoctype')
+        _svg = svg(0, 0, size[0], size[1], **kwargs)
+        super(SVGImageDraw, self).__init__(_svg)
         self.ignore_pil = kwargs.get('ignore_pil')
 
         uri = 'http://www.inkscape.org/namespaces/inkscape'
