@@ -16,7 +16,7 @@
 import copy
 from elements import DiagramNode
 import noderenderer
-from utils import textfolder, Box, Size, XY
+from utils import Box, Size, XY
 from utils.fontmap import FontInfo, FontMap
 from utils.collections import defaultdict
 
@@ -140,6 +140,7 @@ class DiagramMetrics(object):
     span_height = cellsize * 5
 
     def __init__(self, diagram, **kwargs):
+        self.drawer = None
         self.format = kwargs.get('format')
         self.ignore_pil = kwargs.get('ignore_pil')
 
@@ -197,11 +198,13 @@ class DiagramMetrics(object):
 
         return metrics
 
-    def textsize(self, string, width=65535, font=None):
-        lines = textfolder.get((0, 0, width, 65535), string, font,
-                               ignore_pil=self.ignore_pil, format=self.format.lower())
-        textbox = lines.outlinebox
-        return XY(textbox.width, textbox.height + self.line_spacing)
+    def textsize(self, string, font=None, width=65535):
+        if self.drawer:
+            return self.drawer.textsize(string, font, maxwidth=width)
+        else:
+            from blockdiag.utils.textfolder.base import TextFolder
+            folder = TextFolder((0, 0, width, 65535), string, font)
+            return folder.outlinebox.size
 
     def node(self, node):
         renderer = noderenderer.get(node.shape)
@@ -245,23 +248,23 @@ class SpreadSheetMetrics(object):
         self.span_height = defaultdict(lambda: metrics.span_height)
 
     def set_node_width(self, x, width):
-        if width is not None and 0 < width and \
-           (x not in self.node_width or self.node_width[x] < width):
+        if (width is not None and 0 < width and
+           (x not in self.node_width or self.node_width[x] < width)):
             self.node_width[x] = width
 
     def set_node_height(self, y, height):
-        if height is not None and 0 < height and \
-           (y not in self.node_height or self.node_height[y] < height):
+        if (height is not None and 0 < height and
+           (y not in self.node_height or self.node_height[y] < height)):
             self.node_height[y] = height
 
     def set_span_width(self, x, width):
-        if width is not None and 0 < width and \
-           (x not in self.span_width or self.span_width[x] < width):
+        if (width is not None and 0 < width and
+           (x not in self.span_width or self.span_width[x] < width)):
             self.span_width[x] = width
 
     def set_span_height(self, y, height):
-        if height is not None and 0 < height and \
-           (y not in self.span_height or self.span_height[y] < height):
+        if (height is not None and 0 < height and
+           (y not in self.span_height or self.span_height[y] < height)):
             self.span_height[y] = height
 
     def node(self, node, use_padding=True):
