@@ -64,8 +64,11 @@ class Cloud(NodeShape):
         for e in ellipses:
             if kwargs.get('shadow'):
                 e = self.shift_shadow(e)
-                drawer.ellipse(e, fill=fill, outline=fill,
-                               filter='transp-blur')
+                if kwargs.get('style') == 'blur':
+                    drawer.ellipse(e, fill=fill, outline=fill,
+                                   filter='transp-blur')
+                else:
+                    drawer.ellipse(e, fill=fill, outline=fill)
             else:
                 drawer.ellipse(e, fill=self.node.color,
                                outline=self.node.linecolor,
@@ -78,8 +81,11 @@ class Cloud(NodeShape):
         for rect in rects:
             if kwargs.get('shadow'):
                 rect = self.shift_shadow(rect)
-                drawer.rectangle(rect, fill=fill, outline=fill,
-                                 filter='transp-blur')
+                if kwargs.get('style') == 'blur':
+                    drawer.rectangle(rect, fill=fill, outline=fill,
+                                     filter='transp-blur')
+                else:
+                    drawer.rectangle(rect, fill=fill, outline=fill)
             else:
                 drawer.rectangle(rect, fill=self.node.color,
                                  outline=self.node.color)
@@ -108,8 +114,11 @@ class Cloud(NodeShape):
 
         # draw outline
         if kwargs.get('shadow'):
-            drawer.path(path, fill=fill, outline=fill,
-                        filter='transp-blur')
+            if kwargs.get('style') == 'blur':
+                drawer.path(path, fill=fill, outline=fill,
+                            filter='transp-blur')
+            else:
+                drawer.path(path, fill=fill, outline=fill)
         elif self.node.background:
             drawer.path(path, fill=self.node.color, outline=self.node.color)
             drawer.loadImage(self.node.background, self.textbox)
