@@ -41,23 +41,35 @@ class TestRstDirectives(unittest2.TestCase):
 
     def test_setup(self):
         directives.setup()
+        options = directives.directive_options
 
         self.assertIn('blockdiag', docutils._directives)
         self.assertEqual(directives.BlockdiagDirective,
                          docutils._directives['blockdiag'])
-        self.assertEqual('PNG', directives.format)
-        self.assertEqual(False, directives.antialias)
-        self.assertEqual(None, directives.fontpath)
+        self.assertEqual('PNG', options['format'])
+        self.assertEqual(False, options['antialias'])
+        self.assertEqual(None, options['fontpath'])
+        self.assertEqual(False, options['nodoctype'])
+        self.assertEqual(False, options['noviewbox'])
+        self.assertEqual(False, options['inline_svg'])
+        self.assertEqual(False, options['ignore_pil'])
 
     def test_setup_with_args(self):
-        directives.setup(format='SVG', antialias=True, fontpath='/dev/null')
+        directives.setup(format='SVG', antialias=True, fontpath='/dev/null',
+                         nodoctype=True, noviewbox=True, inline_svg=True,
+                         ignore_pil=True)
+        options = directives.directive_options
 
         self.assertIn('blockdiag', docutils._directives)
         self.assertEqual(directives.BlockdiagDirective,
                          docutils._directives['blockdiag'])
-        self.assertEqual('SVG', directives.format)
-        self.assertEqual(True, directives.antialias)
-        self.assertEqual('/dev/null', directives.fontpath)
+        self.assertEqual('SVG', options['format'])
+        self.assertEqual(True, options['antialias'])
+        self.assertEqual('/dev/null', options['fontpath'])
+        self.assertEqual(True, options['nodoctype'])
+        self.assertEqual(True, options['noviewbox'])
+        self.assertEqual(True, options['inline_svg'])
+        self.assertEqual(True, options['ignore_pil'])
 
     @stderr_wrapper
     @setup_directive_base
@@ -188,6 +200,102 @@ class TestRstDirectives(unittest2.TestCase):
         self.assertEqual(0, doctree[0]['uri'].index(path))
         self.assertFalse(0, doctree[0]['target'].index(path))
 
+    @use_tmpdir
+    def test_block_nodoctype_false(self, path):
+        directives.setup(format='SVG', outputdir=path, nodoctype=False)
+        text = ".. blockdiag::\n   :alt: hello world\n\n   { A -> B }"
+        doctree = publish_doctree(text)
+        self.assertEqual(1, len(doctree))
+        self.assertEqual(nodes.image, type(doctree[0]))
+        svg = open(doctree[0]['uri']).read()
+        self.assertEqual("<?xml version='1.0' encoding='UTF-8'?>\n"
+                         "<!DOCTYPE ", svg[:49])
+
+    @use_tmpdir
+    def test_block_nodoctype_true(self, path):
+        directives.setup(format='SVG', outputdir=path, nodoctype=True)
+        text = ".. blockdiag::\n   :alt: hello world\n\n   { A -> B }"
+        doctree = publish_doctree(text)
+        self.assertEqual(1, len(doctree))
+        self.assertEqual(nodes.image, type(doctree[-1]))
+        svg = open(doctree[0]['uri']).read()
+        self.assertNotEqual("<?xml version='1.0' encoding='UTF-8'?>\n"
+                            "<!DOCTYPE ", svg[:49])
+
+    @use_tmpdir
+    def test_block_noviewbox_false(self, path):
+        directives.setup(format='SVG', outputdir=path, noviewbox=False)
+        text = ".. blockdiag::\n   :alt: hello world\n\n   { A -> B }"
+        doctree = publish_doctree(text)
+        self.assertEqual(1, len(doctree))
+        self.assertEqual(nodes.image, type(doctree[0]))
+        svg = open(doctree[0]['uri']).read()
+        self.assertRegexpMatches(svg, '<svg viewBox="0 0 \d+ \d+" ')
+
+    @use_tmpdir
+    def test_block_noviewbox_true(self, path):
+        directives.setup(format='SVG', outputdir=path, noviewbox=True)
+        text = ".. blockdiag::\n   :alt: hello world\n\n   { A -> B }"
+        doctree = publish_doctree(text)
+        self.assertEqual(1, len(doctree))
+        self.assertEqual(nodes.image, type(doctree[0]))
+        svg = open(doctree[0]['uri']).read()
+        self.assertRegexpMatches(svg, '<svg height="\d+" width="\d+" ')
+
+    @use_tmpdir
+    def test_block_inline_svg_false(self, path):
+        directives.setup(format='SVG', outputdir=path, inline_svg=False)
+        text = ".. blockdiag::\n   :alt: hello world\n\n   { A -> B }"
+        doctree = publish_doctree(text)
+        self.assertEqual(1, len(doctree))
+        self.assertEqual(nodes.image, type(doctree[0]))
+        self.assertEqual(1, len(os.listdir(path)))
+
+    @use_tmpdir
+    def test_block_inline_svg_true(self, path):
+        directives.setup(format='SVG', outputdir=path, inline_svg=True)
+        text = ".. blockdiag::\n   :alt: hello world\n\n   { A -> B }"
+        doctree = publish_doctree(text)
+        self.assertEqual(1, len(doctree))
+        self.assertEqual(nodes.raw, type(doctree[0]))
+        self.assertEqual('html', doctree[0]['format'])
+        self.assertEqual(nodes.Text, type(doctree[0][0]))
+        self.assertEqual("<?xml version='1.0' encoding='UTF-8'?>\n"
+                         "<!DOCTYPE ", doctree[0][0][:49])
+        self.assertEqual(0, len(os.listdir(path)))
+
+    @use_tmpdir
+    def test_block_inline_svg_true_but_nonsvg_format(self, path):
+        directives.setup(format='PNG', outputdir=path, inline_svg=True)
+        text = ".. blockdiag::\n   :alt: hello world\n\n   { A -> B }"
+        doctree = publish_doctree(text)
+        self.assertEqual(1, len(doctree))
+        self.assertEqual(nodes.image, type(doctree[0]))
+
+    @use_tmpdir
+    def test_block_ignore_pil_false(self, path):
+        directives.setup(format='SVG', outputdir=path, ignore_pil=False)
+        text = ".. blockdiag::\n   :alt: hello world\n\n   { A -> B }"
+        doctree = publish_doctree(text)
+        self.assertEqual(1, len(doctree))
+        self.assertEqual(nodes.image, type(doctree[0]))
+
+    @use_tmpdir
+    def test_block_ignore_pil_true(self, path):
+        directives.setup(format='SVG', outputdir=path, ignore_pil=True)
+        text = ".. blockdiag::\n   :alt: hello world\n\n   { A -> B }"
+        doctree = publish_doctree(text)
+        self.assertEqual(1, len(doctree))
+        self.assertEqual(nodes.image, type(doctree[0]))
+
+    @use_tmpdir
+    def test_desctable_without_description(self, path):
+        directives.setup(format='SVG', outputdir=path)
+        text = ".. blockdiag::\n   :desctable:\n\n   { A -> B }"
+        doctree = publish_doctree(text)
+        self.assertEqual(1, len(doctree))
+        self.assertEqual(nodes.image, type(doctree[0]))
+
     @use_tmpdir
     def test_desctable_without_description(self, path):
         directives.setup(format='SVG', outputdir=path)
